"""Fill in a module description here"""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/client/ExecutionError.ipynb.

# %% auto 0
__all__ = ['ExecutionError']

# %% ../../nbs/client/ExecutionError.ipynb 3
class ExecutionError(Exception):
    def __init__(self, message):
        super().__init__(message)
